# coding: utf-8

"""
    Visitor Identification

    The Visitor Identification API allows you to pass identification information to the HubSpot chat widget for otherwise unknown visitors that were verified by your own authentication system.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.conversations.visitor_identification.configuration import Configuration


class IdentificationTokenGenerationRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"first_name": "str", "last_name": "str", "email": "str"}

    attribute_map = {"first_name": "firstName", "last_name": "lastName", "email": "email"}

    def __init__(self, first_name=None, last_name=None, email=None, local_vars_configuration=None):  # noqa: E501
        """IdentificationTokenGenerationRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._first_name = None
        self._last_name = None
        self._email = None
        self.discriminator = None

        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        self.email = email

    @property
    def first_name(self):
        """Gets the first_name of this IdentificationTokenGenerationRequest.  # noqa: E501

        The first name of the visitor that you wish to identify. This value will only be set in HubSpot for new contacts and existing contacts where first name is unknown. Optional.  # noqa: E501

        :return: The first_name of this IdentificationTokenGenerationRequest.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this IdentificationTokenGenerationRequest.

        The first name of the visitor that you wish to identify. This value will only be set in HubSpot for new contacts and existing contacts where first name is unknown. Optional.  # noqa: E501

        :param first_name: The first_name of this IdentificationTokenGenerationRequest.  # noqa: E501
        :type first_name: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this IdentificationTokenGenerationRequest.  # noqa: E501

        The last name of the visitor that you wish to identify. This value will only be set in HubSpot for new contacts and existing contacts where last name is unknown. Optional.  # noqa: E501

        :return: The last_name of this IdentificationTokenGenerationRequest.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this IdentificationTokenGenerationRequest.

        The last name of the visitor that you wish to identify. This value will only be set in HubSpot for new contacts and existing contacts where last name is unknown. Optional.  # noqa: E501

        :param last_name: The last_name of this IdentificationTokenGenerationRequest.  # noqa: E501
        :type last_name: str
        """

        self._last_name = last_name

    @property
    def email(self):
        """Gets the email of this IdentificationTokenGenerationRequest.  # noqa: E501

        The email of the visitor that you wish to identify  # noqa: E501

        :return: The email of this IdentificationTokenGenerationRequest.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this IdentificationTokenGenerationRequest.

        The email of the visitor that you wish to identify  # noqa: E501

        :param email: The email of this IdentificationTokenGenerationRequest.  # noqa: E501
        :type email: str
        """
        if self.local_vars_configuration.client_side_validation and email is None:  # noqa: E501
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IdentificationTokenGenerationRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IdentificationTokenGenerationRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Contacts

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from os.path import dirname, abspath, exists
from setuptools import setup, find_packages  # noqa: H301


NAME = "hubspot-api-client-extended"

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "requests >= 2.31.0",
    "urllib3 >= 1.15, < 3.0",
    "six >= 1.10, < 2.0",
    "certifi >= 2023.1.1",
    "python-dateutil >= 2.8.2",
    "importlib-metadata<5; python_version<'3.8'"
]
DEV_REQUIRES = ["pytest", "black"]

DIR_PATH = dirname(abspath(__file__))

with open(DIR_PATH + "/VERSION", "r", encoding="utf-8") as f:
    VERSION = f.readline().strip()

LONG_DESCRIPTION = None
if exists(DIR_PATH + "/README.md"):
    with open(DIR_PATH + "/README.md", "r", encoding="utf-8") as f:
        LONG_DESCRIPTION = f.read()

setup(
    name=NAME,
    packages=find_packages(),
    version=VERSION,
    description="extended HubSpot API client",
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    url="https://github.com/ddanssaert/hubspot-api-python-extended",
    author="HubSpot",
    author_email="support@hubspot.com",
    install_requires=REQUIRES,
    extras_require={"dev": DEV_REQUIRES},
    python_requires=">=3.7",
    include_package_data=True,
    license='Apache-2.0',
)



from urllib3.util.retry import Retry


class Client:
    def __init__(
        self,
        api_key: str = None,
        access_token: str = None,
        retry: Retry = None,
        **kwargs
    ):
        self.config = dict(
            {"api_key": api_key, "access_token": access_token, "retry": retry}, **kwargs
        )

    @classmethod
    def create(cls, **kwargs):
        return cls(**kwargs)

    @property
    def access_token(self):
        return self.config["access_token"]

    @access_token.setter
    def access_token(self, value):
        self.config["access_token"] = value

    @property
    def api_key(self):
        return self.config["api_key"]

    @api_key.setter
    def api_key(self, value):
        self.config["api_key"] = value

    @property
    def oauth(self):
        from .discovery.oauth.discovery import Discovery as OauthDiscovery
        return OauthDiscovery(self.config)

    @property
    def automation(self):
        from .discovery.automation.discovery import Discovery as AutomationDiscovery
        return AutomationDiscovery(self.config)

    @property
    def cms(self):
        from .discovery.cms.discovery import Discovery as CmsDiscovery
        return CmsDiscovery(self.config)

    @property
    def communication_preferences(self):
        from .discovery.communication_preferences.discovery import Discovery as CommunicationPreferencesDiscovery
        return CommunicationPreferencesDiscovery(self.config)

    @property
    def conversations(self):
        from .discovery.conversations.discovery import Discovery as ConversationsDiscovery
        return ConversationsDiscovery(self.config)

    @property
    def crm(self):
        from .discovery.crm.discovery import Discovery as CrmDiscovery
        return CrmDiscovery(self.config)

    @property
    def events(self):
        from .discovery.events.discovery import Discovery as EventsDiscovery
        return EventsDiscovery(self.config)

    @property
    def files(self):
        from .discovery.files.discovery import Discovery as FilesDiscovery
        return FilesDiscovery(self.config)

    @property
    def marketing(self):
        from .discovery.marketing.discovery import Discovery as MarketingDiscovery
        return MarketingDiscovery(self.config)

    @property
    def settings(self):
        from .discovery.settings.discovery import Discovery as SettingsDiscovery
        return SettingsDiscovery(self.config)

    @property
    def webhooks(self):
        from .discovery.webhooks.discovery import Discovery as WebhooksDiscovery
        return WebhooksDiscovery(self.config)

    def api_request(self, options):
        from .utils.requests.http_request_builder import Request
        request = Request(self.config, options)
        return request.send()



# coding: utf-8

# flake8: noqa

"""
    Settings User Provisioning

    Add, manage, and remove users from your account  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.settings.users.api.roles_api import RolesApi
from hubspot.settings.users.api.teams_api import TeamsApi
from hubspot.settings.users.api.users_api import UsersApi

# import ApiClient
from hubspot.settings.users.api_client import ApiClient
from hubspot.settings.users.configuration import Configuration
from hubspot.settings.users.exceptions import OpenApiException
from hubspot.settings.users.exceptions import ApiTypeError
from hubspot.settings.users.exceptions import ApiValueError
from hubspot.settings.users.exceptions import ApiKeyError
from hubspot.settings.users.exceptions import ApiAttributeError
from hubspot.settings.users.exceptions import ApiException

# import models into sdk package
from hubspot.settings.users.models.collection_response_public_permission_set_no_paging import CollectionResponsePublicPermissionSetNoPaging
from hubspot.settings.users.models.collection_response_public_team_no_paging import CollectionResponsePublicTeamNoPaging
from hubspot.settings.users.models.collection_response_public_user_forward_paging import CollectionResponsePublicUserForwardPaging
from hubspot.settings.users.models.error import Error
from hubspot.settings.users.models.error_detail import ErrorDetail
from hubspot.settings.users.models.forward_paging import ForwardPaging
from hubspot.settings.users.models.next_page import NextPage
from hubspot.settings.users.models.public_permission_set import PublicPermissionSet
from hubspot.settings.users.models.public_team import PublicTeam
from hubspot.settings.users.models.public_user import PublicUser
from hubspot.settings.users.models.public_user_update import PublicUserUpdate
from hubspot.settings.users.models.user_provision_request import UserProvisionRequest



# coding: utf-8

# flake8: noqa
"""
    Associations Schema

    Associations define the relationships between objects in HubSpot. These endpoints allow you to create, read, and remove associations.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from hubspot.crm.associations.schema.models.collection_response_public_association_definition_no_paging import CollectionResponsePublicAssociationDefinitionNoPaging
from hubspot.crm.associations.schema.models.error import Error
from hubspot.crm.associations.schema.models.error_detail import ErrorDetail
from hubspot.crm.associations.schema.models.public_association_definition import PublicAssociationDefinition



from ...discovery_base import DiscoveryBase

class Discovery(DiscoveryBase):
    @property
    def cards(self):
        from .cards.discovery import Discovery as CardsDiscovery
        return CardsDiscovery(self.config)

    @property
    def calling(self):
        from .calling.discovery import Discovery as CallingDiscovery
        return CallingDiscovery(self.config)

    @property
    def videoconferencing(self):
        from .videoconferencing.discovery import Discovery as VideoconferencingDiscovery
        return VideoconferencingDiscovery(self.config)



# coding: utf-8

"""
    Transactional Single Send

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.marketing.transactional.api_client import ApiClient
from hubspot.marketing.transactional.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class PublicSMTPTokensApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def archive_token(self, token_id, **kwargs):  # noqa: E501
        """Delete a single token by ID.  # noqa: E501

        Delete a single token by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive_token(token_id, async_req=True)
        >>> result = thread.get()

        :param token_id: Identifier generated when a token is created. (required)
        :type token_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.archive_token_with_http_info(token_id, **kwargs)  # noqa: E501

    def archive_token_with_http_info(self, token_id, **kwargs):  # noqa: E501
        """Delete a single token by ID.  # noqa: E501

        Delete a single token by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive_token_with_http_info(token_id, async_req=True)
        >>> result = thread.get()

        :param token_id: Identifier generated when a token is created. (required)
        :type token_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["token_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method archive_token" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'token_id' is set
        if self.api_client.client_side_validation and local_var_params.get("token_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `token_id` when calling `archive_token`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "token_id" in local_var_params:
            path_params["tokenId"] = local_var_params["token_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/marketing/v3/transactional/smtp-tokens/{tokenId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def create_token(self, smtp_api_token_request_egg, **kwargs):  # noqa: E501
        """Create a SMTP API token.  # noqa: E501

        Create a SMTP API token.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_token(smtp_api_token_request_egg, async_req=True)
        >>> result = thread.get()

        :param smtp_api_token_request_egg: A request object that includes the campaign name tied to the token and whether contacts should be created for email recipients. (required)
        :type smtp_api_token_request_egg: SmtpApiTokenRequestEgg
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SmtpApiTokenView
        """
        kwargs["_return_http_data_only"] = True
        return self.create_token_with_http_info(smtp_api_token_request_egg, **kwargs)  # noqa: E501

    def create_token_with_http_info(self, smtp_api_token_request_egg, **kwargs):  # noqa: E501
        """Create a SMTP API token.  # noqa: E501

        Create a SMTP API token.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_token_with_http_info(smtp_api_token_request_egg, async_req=True)
        >>> result = thread.get()

        :param smtp_api_token_request_egg: A request object that includes the campaign name tied to the token and whether contacts should be created for email recipients. (required)
        :type smtp_api_token_request_egg: SmtpApiTokenRequestEgg
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(SmtpApiTokenView, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["smtp_api_token_request_egg"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method create_token" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'smtp_api_token_request_egg' is set
        if self.api_client.client_side_validation and local_var_params.get("smtp_api_token_request_egg") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `smtp_api_token_request_egg` when calling `create_token`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "smtp_api_token_request_egg" in local_var_params:
            body_params = local_var_params["smtp_api_token_request_egg"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            201: "SmtpApiTokenView",
        }

        return self.api_client.call_api(
            "/marketing/v3/transactional/smtp-tokens",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_token_by_id(self, token_id, **kwargs):  # noqa: E501
        """Query a single token by ID.  # noqa: E501

        Query a single token by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_token_by_id(token_id, async_req=True)
        >>> result = thread.get()

        :param token_id: Identifier generated when a token is created. (required)
        :type token_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SmtpApiTokenView
        """
        kwargs["_return_http_data_only"] = True
        return self.get_token_by_id_with_http_info(token_id, **kwargs)  # noqa: E501

    def get_token_by_id_with_http_info(self, token_id, **kwargs):  # noqa: E501
        """Query a single token by ID.  # noqa: E501

        Query a single token by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_token_by_id_with_http_info(token_id, async_req=True)
        >>> result = thread.get()

        :param token_id: Identifier generated when a token is created. (required)
        :type token_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(SmtpApiTokenView, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["token_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_token_by_id" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'token_id' is set
        if self.api_client.client_side_validation and local_var_params.get("token_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `token_id` when calling `get_token_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "token_id" in local_var_params:
            path_params["tokenId"] = local_var_params["token_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "SmtpApiTokenView",
        }

        return self.api_client.call_api(
            "/marketing/v3/transactional/smtp-tokens/{tokenId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_tokens_page(self, **kwargs):  # noqa: E501
        """Query SMTP API tokens by campaign name or an emailCampaignId.  # noqa: E501

        Query multiple SMTP API tokens by campaign name or a single token by emailCampaignId.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_tokens_page(async_req=True)
        >>> result = thread.get()

        :param campaign_name: A name for the campaign tied to the SMTP API token.
        :type campaign_name: str
        :param email_campaign_id: Identifier assigned to the campaign provided during the token creation.
        :type email_campaign_id: str
        :param after: Starting point to get the next set of results.
        :type after: str
        :param limit: Maximum number of tokens to return.
        :type limit: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CollectionResponseSmtpApiTokenViewForwardPaging
        """
        kwargs["_return_http_data_only"] = True
        return self.get_tokens_page_with_http_info(**kwargs)  # noqa: E501

    def get_tokens_page_with_http_info(self, **kwargs):  # noqa: E501
        """Query SMTP API tokens by campaign name or an emailCampaignId.  # noqa: E501

        Query multiple SMTP API tokens by campaign name or a single token by emailCampaignId.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_tokens_page_with_http_info(async_req=True)
        >>> result = thread.get()

        :param campaign_name: A name for the campaign tied to the SMTP API token.
        :type campaign_name: str
        :param email_campaign_id: Identifier assigned to the campaign provided during the token creation.
        :type email_campaign_id: str
        :param after: Starting point to get the next set of results.
        :type after: str
        :param limit: Maximum number of tokens to return.
        :type limit: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CollectionResponseSmtpApiTokenViewForwardPaging, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["campaign_name", "email_campaign_id", "after", "limit"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_tokens_page" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if local_var_params.get("campaign_name") is not None:  # noqa: E501
            query_params.append(("campaignName", local_var_params["campaign_name"]))  # noqa: E501
        if local_var_params.get("email_campaign_id") is not None:  # noqa: E501
            query_params.append(("emailCampaignId", local_var_params["email_campaign_id"]))  # noqa: E501
        if local_var_params.get("after") is not None:  # noqa: E501
            query_params.append(("after", local_var_params["after"]))  # noqa: E501
        if local_var_params.get("limit") is not None:  # noqa: E501
            query_params.append(("limit", local_var_params["limit"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "CollectionResponseSmtpApiTokenViewForwardPaging",
        }

        return self.api_client.call_api(
            "/marketing/v3/transactional/smtp-tokens",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def reset_password(self, token_id, **kwargs):  # noqa: E501
        """Reset the password of an existing token.  # noqa: E501

        Allows the creation of a replacement password for a given token. Once the password is successfully reset, the old password for the token will be invalid.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.reset_password(token_id, async_req=True)
        >>> result = thread.get()

        :param token_id: Identifier generated when a token is created. (required)
        :type token_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SmtpApiTokenView
        """
        kwargs["_return_http_data_only"] = True
        return self.reset_password_with_http_info(token_id, **kwargs)  # noqa: E501

    def reset_password_with_http_info(self, token_id, **kwargs):  # noqa: E501
        """Reset the password of an existing token.  # noqa: E501

        Allows the creation of a replacement password for a given token. Once the password is successfully reset, the old password for the token will be invalid.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.reset_password_with_http_info(token_id, async_req=True)
        >>> result = thread.get()

        :param token_id: Identifier generated when a token is created. (required)
        :type token_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(SmtpApiTokenView, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["token_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method reset_password" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'token_id' is set
        if self.api_client.client_side_validation and local_var_params.get("token_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `token_id` when calling `reset_password`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "token_id" in local_var_params:
            path_params["tokenId"] = local_var_params["token_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "SmtpApiTokenView",
        }

        return self.api_client.call_api(
            "/marketing/v3/transactional/smtp-tokens/{tokenId}/password-reset",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )



# coding: utf-8

# flake8: noqa

"""
    Public App Crm Cards

    Allows an app to extend the CRM UI by surfacing custom cards in the sidebar of record pages. These cards are defined up-front as part of app configuration, then populated by external data fetch requests when the record page is accessed by a user.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from hubspot.crm.extensions.cards.api.cards_api import CardsApi
from hubspot.crm.extensions.cards.api.sample_response_api import SampleResponseApi

# import ApiClient
from hubspot.crm.extensions.cards.api_client import ApiClient
from hubspot.crm.extensions.cards.configuration import Configuration
from hubspot.crm.extensions.cards.exceptions import OpenApiException
from hubspot.crm.extensions.cards.exceptions import ApiTypeError
from hubspot.crm.extensions.cards.exceptions import ApiValueError
from hubspot.crm.extensions.cards.exceptions import ApiKeyError
from hubspot.crm.extensions.cards.exceptions import ApiAttributeError
from hubspot.crm.extensions.cards.exceptions import ApiException

# import models into sdk package
from hubspot.crm.extensions.cards.models.action_confirmation_body import ActionConfirmationBody
from hubspot.crm.extensions.cards.models.action_hook_action_body import ActionHookActionBody
from hubspot.crm.extensions.cards.models.card_actions import CardActions
from hubspot.crm.extensions.cards.models.card_audit_response import CardAuditResponse
from hubspot.crm.extensions.cards.models.card_create_request import CardCreateRequest
from hubspot.crm.extensions.cards.models.card_display_body import CardDisplayBody
from hubspot.crm.extensions.cards.models.card_display_property import CardDisplayProperty
from hubspot.crm.extensions.cards.models.card_fetch_body import CardFetchBody
from hubspot.crm.extensions.cards.models.card_fetch_body_patch import CardFetchBodyPatch
from hubspot.crm.extensions.cards.models.card_object_type_body import CardObjectTypeBody
from hubspot.crm.extensions.cards.models.card_patch_request import CardPatchRequest
from hubspot.crm.extensions.cards.models.display_option import DisplayOption
from hubspot.crm.extensions.cards.models.error import Error
from hubspot.crm.extensions.cards.models.error_detail import ErrorDetail
from hubspot.crm.extensions.cards.models.i_frame_action_body import IFrameActionBody
from hubspot.crm.extensions.cards.models.integrator_card_payload_response import IntegratorCardPayloadResponse
from hubspot.crm.extensions.cards.models.integrator_object_result import IntegratorObjectResult
from hubspot.crm.extensions.cards.models.integrator_object_result_actions_inner import IntegratorObjectResultActionsInner
from hubspot.crm.extensions.cards.models.object_token import ObjectToken
from hubspot.crm.extensions.cards.models.public_card_fetch_body import PublicCardFetchBody
from hubspot.crm.extensions.cards.models.public_card_list_response import PublicCardListResponse
from hubspot.crm.extensions.cards.models.public_card_response import PublicCardResponse
from hubspot.crm.extensions.cards.models.top_level_actions import TopLevelActions



# coding: utf-8

"""
    CRM Objects

    CRM objects such as companies, contacts, deals, line items, products, tickets, and quotes are standard objects in HubSpot’s CRM. These core building blocks support custom properties, store critical information, and play a central role in the HubSpot application.  ## Supported Object Types  This API provides access to collections of CRM objects, which return a map of property names to values. Each object type has its own set of default properties, which can be found by exploring the [CRM Object Properties API](https://developers.hubspot.com/docs/methods/crm-properties/crm-properties-overview).  |Object Type |Properties returned by default | |--|--| | `companies` | `name`, `domain` | | `contacts` | `firstname`, `lastname`, `email` | | `deals` | `dealname`, `amount`, `closedate`, `pipeline`, `dealstage` | | `products` | `name`, `description`, `price` | | `tickets` | `content`, `hs_pipeline`, `hs_pipeline_stage`, `hs_ticket_category`, `hs_ticket_priority`, `subject` |  Find a list of all properties for an object type using the [CRM Object Properties](https://developers.hubspot.com/docs/methods/crm-properties/get-properties) API. e.g. `GET https://api.hubapi.com/properties/v2/companies/properties`. Change the properties returned in the response using the `properties` array in the request body.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.objects.configuration import Configuration


class StandardError(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "sub_category": "object",
        "context": "dict[str, list[str]]",
        "links": "dict[str, str]",
        "id": "str",
        "category": "str",
        "message": "str",
        "errors": "list[ErrorDetail]",
        "status": "str",
    }

    attribute_map = {"sub_category": "subCategory", "context": "context", "links": "links", "id": "id", "category": "category", "message": "message", "errors": "errors", "status": "status"}

    def __init__(self, sub_category=None, context=None, links=None, id=None, category=None, message=None, errors=None, status=None, local_vars_configuration=None):  # noqa: E501
        """StandardError - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._sub_category = None
        self._context = None
        self._links = None
        self._id = None
        self._category = None
        self._message = None
        self._errors = None
        self._status = None
        self.discriminator = None

        if sub_category is not None:
            self.sub_category = sub_category
        self.context = context
        self.links = links
        if id is not None:
            self.id = id
        self.category = category
        self.message = message
        self.errors = errors
        self.status = status

    @property
    def sub_category(self):
        """Gets the sub_category of this StandardError.  # noqa: E501


        :return: The sub_category of this StandardError.  # noqa: E501
        :rtype: object
        """
        return self._sub_category

    @sub_category.setter
    def sub_category(self, sub_category):
        """Sets the sub_category of this StandardError.


        :param sub_category: The sub_category of this StandardError.  # noqa: E501
        :type sub_category: object
        """

        self._sub_category = sub_category

    @property
    def context(self):
        """Gets the context of this StandardError.  # noqa: E501


        :return: The context of this StandardError.  # noqa: E501
        :rtype: dict[str, list[str]]
        """
        return self._context

    @context.setter
    def context(self, context):
        """Sets the context of this StandardError.


        :param context: The context of this StandardError.  # noqa: E501
        :type context: dict[str, list[str]]
        """
        if self.local_vars_configuration.client_side_validation and context is None:  # noqa: E501
            raise ValueError("Invalid value for `context`, must not be `None`")  # noqa: E501

        self._context = context

    @property
    def links(self):
        """Gets the links of this StandardError.  # noqa: E501


        :return: The links of this StandardError.  # noqa: E501
        :rtype: dict[str, str]
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this StandardError.


        :param links: The links of this StandardError.  # noqa: E501
        :type links: dict[str, str]
        """
        if self.local_vars_configuration.client_side_validation and links is None:  # noqa: E501
            raise ValueError("Invalid value for `links`, must not be `None`")  # noqa: E501

        self._links = links

    @property
    def id(self):
        """Gets the id of this StandardError.  # noqa: E501


        :return: The id of this StandardError.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this StandardError.


        :param id: The id of this StandardError.  # noqa: E501
        :type id: str
        """

        self._id = id

    @property
    def category(self):
        """Gets the category of this StandardError.  # noqa: E501


        :return: The category of this StandardError.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this StandardError.


        :param category: The category of this StandardError.  # noqa: E501
        :type category: str
        """
        if self.local_vars_configuration.client_side_validation and category is None:  # noqa: E501
            raise ValueError("Invalid value for `category`, must not be `None`")  # noqa: E501

        self._category = category

    @property
    def message(self):
        """Gets the message of this StandardError.  # noqa: E501


        :return: The message of this StandardError.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this StandardError.


        :param message: The message of this StandardError.  # noqa: E501
        :type message: str
        """
        if self.local_vars_configuration.client_side_validation and message is None:  # noqa: E501
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    @property
    def errors(self):
        """Gets the errors of this StandardError.  # noqa: E501


        :return: The errors of this StandardError.  # noqa: E501
        :rtype: list[ErrorDetail]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this StandardError.


        :param errors: The errors of this StandardError.  # noqa: E501
        :type errors: list[ErrorDetail]
        """
        if self.local_vars_configuration.client_side_validation and errors is None:  # noqa: E501
            raise ValueError("Invalid value for `errors`, must not be `None`")  # noqa: E501

        self._errors = errors

    @property
    def status(self):
        """Gets the status of this StandardError.  # noqa: E501


        :return: The status of this StandardError.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this StandardError.


        :param status: The status of this StandardError.  # noqa: E501
        :type status: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StandardError):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StandardError):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Files

    Upload and manage files.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.files.configuration import Configuration


class FolderUpdateInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"parent_folder_id": "int", "name": "str"}

    attribute_map = {"parent_folder_id": "parentFolderId", "name": "name"}

    def __init__(self, parent_folder_id=None, name=None, local_vars_configuration=None):  # noqa: E501
        """FolderUpdateInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._parent_folder_id = None
        self._name = None
        self.discriminator = None

        if parent_folder_id is not None:
            self.parent_folder_id = parent_folder_id
        if name is not None:
            self.name = name

    @property
    def parent_folder_id(self):
        """Gets the parent_folder_id of this FolderUpdateInput.  # noqa: E501

        New parent folderId. If changed, the folder and all it's children will be moved into the specified folder. parentFolderId and parentFolderPath cannot be specified at the same time.  # noqa: E501

        :return: The parent_folder_id of this FolderUpdateInput.  # noqa: E501
        :rtype: int
        """
        return self._parent_folder_id

    @parent_folder_id.setter
    def parent_folder_id(self, parent_folder_id):
        """Sets the parent_folder_id of this FolderUpdateInput.

        New parent folderId. If changed, the folder and all it's children will be moved into the specified folder. parentFolderId and parentFolderPath cannot be specified at the same time.  # noqa: E501

        :param parent_folder_id: The parent_folder_id of this FolderUpdateInput.  # noqa: E501
        :type parent_folder_id: int
        """

        self._parent_folder_id = parent_folder_id

    @property
    def name(self):
        """Gets the name of this FolderUpdateInput.  # noqa: E501

        New name. If specified the folder's name and fullPath will change. All children of the folder will be updated accordingly.  # noqa: E501

        :return: The name of this FolderUpdateInput.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FolderUpdateInput.

        New name. If specified the folder's name and fullPath will change. All children of the folder will be updated accordingly.  # noqa: E501

        :param name: The name of this FolderUpdateInput.  # noqa: E501
        :type name: str
        """

        self._name = name

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FolderUpdateInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FolderUpdateInput):
            return True

        return self.to_dict() != other.to_dict()



import hubspot.events as api_client
from ..discovery_base import DiscoveryBase


class Discovery(DiscoveryBase):

    @property
    def events_api(self) -> api_client.EventsApi:
        return self._configure_api_client(api_client, "EventsApi")

    @property
    def send(self):
        from .send.discovery import Discovery as SendDiscovery
        return SendDiscovery(self.config)




# coding: utf-8

"""
    Visitor Identification

    The Visitor Identification API allows you to pass identification information to the HubSpot chat widget for otherwise unknown visitors that were verified by your own authentication system.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.conversations.visitor_identification.api_client import ApiClient
from hubspot.conversations.visitor_identification.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class GenerateApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def generate_token(self, identification_token_generation_request, **kwargs):  # noqa: E501
        """Generate a token  # noqa: E501

        Generates a new visitor identification token. This token will be unique every time this endpoint is called, even if called with the same email address. This token is temporary and will expire after 12 hours  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.generate_token(identification_token_generation_request, async_req=True)
        >>> result = thread.get()

        :param identification_token_generation_request: (required)
        :type identification_token_generation_request: IdentificationTokenGenerationRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: IdentificationTokenResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.generate_token_with_http_info(identification_token_generation_request, **kwargs)  # noqa: E501

    def generate_token_with_http_info(self, identification_token_generation_request, **kwargs):  # noqa: E501
        """Generate a token  # noqa: E501

        Generates a new visitor identification token. This token will be unique every time this endpoint is called, even if called with the same email address. This token is temporary and will expire after 12 hours  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.generate_token_with_http_info(identification_token_generation_request, async_req=True)
        >>> result = thread.get()

        :param identification_token_generation_request: (required)
        :type identification_token_generation_request: IdentificationTokenGenerationRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(IdentificationTokenResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["identification_token_generation_request"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method generate_token" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'identification_token_generation_request' is set
        if self.api_client.client_side_validation and local_var_params.get("identification_token_generation_request") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `identification_token_generation_request` when calling `generate_token`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "identification_token_generation_request" in local_var_params:
            body_params = local_var_params["identification_token_generation_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "IdentificationTokenResponse",
        }

        return self.api_client.call_api(
            "/visitor-identification/v3/tokens/create",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )



# coding: utf-8

"""
    CMS Site Search

    Use these endpoints for searching content on your HubSpot hosted CMS website(s).  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.cms.site_search.api_client import ApiClient
from hubspot.cms.site_search.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class PublicApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_by_id(self, content_id, **kwargs):  # noqa: E501
        """Get indexed properties.  # noqa: E501

        For a given account and document ID (page ID, blog post ID, HubDB row ID, etc.), return all indexed data for that document. This is useful when debugging why a particular document is not returned from a custom search.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_id(content_id, async_req=True)
        >>> result = thread.get()

        :param content_id: ID of the target document when searching for indexed properties. (required)
        :type content_id: str
        :param type: The type of document. Can be one of `SITE_PAGE`, `BLOG_POST`, or `KNOWLEDGE_ARTICLE`.
        :type type: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: IndexedData
        """
        kwargs["_return_http_data_only"] = True
        return self.get_by_id_with_http_info(content_id, **kwargs)  # noqa: E501

    def get_by_id_with_http_info(self, content_id, **kwargs):  # noqa: E501
        """Get indexed properties.  # noqa: E501

        For a given account and document ID (page ID, blog post ID, HubDB row ID, etc.), return all indexed data for that document. This is useful when debugging why a particular document is not returned from a custom search.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_id_with_http_info(content_id, async_req=True)
        >>> result = thread.get()

        :param content_id: ID of the target document when searching for indexed properties. (required)
        :type content_id: str
        :param type: The type of document. Can be one of `SITE_PAGE`, `BLOG_POST`, or `KNOWLEDGE_ARTICLE`.
        :type type: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(IndexedData, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["content_id", "type"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_by_id" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'content_id' is set
        if self.api_client.client_side_validation and local_var_params.get("content_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `content_id` when calling `get_by_id`")  # noqa: E501

        if self.api_client.client_side_validation and "content_id" in local_var_params and not re.search(r".*", local_var_params["content_id"]):  # noqa: E501
            raise ApiValueError("Invalid value for parameter `content_id` when calling `get_by_id`, must conform to the pattern `/.*/`")  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "content_id" in local_var_params:
            path_params["contentId"] = local_var_params["content_id"]  # noqa: E501

        query_params = []
        if local_var_params.get("type") is not None:  # noqa: E501
            query_params.append(("type", local_var_params["type"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "IndexedData",
        }

        return self.api_client.call_api(
            "/cms/v3/site-search/indexed-data/{contentId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def search(self, **kwargs):  # noqa: E501
        """Search your site.  # noqa: E501

        Returns any website content matching the given search criteria for a given HubSpot account. Searches can be filtered by content type, domain, or URL path.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.search(async_req=True)
        >>> result = thread.get()

        :param q: The term to search for.
        :type q: str
        :param limit: Specifies the number of results to be returned in a single response. Defaults to `10`. Maximum value is `100`.
        :type limit: int
        :param offset: Used to page through the results. If there are more results than specified by the `limit` parameter, you will need to use the value of offset returned in the previous request to get the next set of results.
        :type offset: int
        :param language: Specifies the language of content to be searched. This value must be a valid [ISO 639-1 language code](https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes) (e.g. `es` for Spanish)
        :type language: str
        :param match_prefix: Inverts the behavior of the pathPrefix filter when set to `false`. Defaults to `true`.
        :type match_prefix: bool
        :param autocomplete: Specifies whether or not you are showing autocomplete results. Defaults to false.
        :type autocomplete: bool
        :param popularity_boost: Specifies how strongly a result is boosted based on its view count. Defaults to 1.0.
        :type popularity_boost: float
        :param boost_limit: Specifies the maximum amount a result will be boosted based on its view count. Defaults to 5.0. Read more about elasticsearch boosting [here](https://www.elastic.co/guide/en/elasticsearch/reference/current/mapping-boost.html).
        :type boost_limit: float
        :param boost_recent: Specifies a relative time window where scores of documents published outside this time window decay. This can only be used for blog posts. For example, boostRecent=10d will boost documents published within the last 10 days. Supported timeunits are ms (milliseconds), s (seconds), m (minutes), h (hours), d (days).
        :type boost_recent: str
        :param table_id: Specifies a specific HubDB table to search. Only returns results from the specified table. Can be used in tandem with the `hubdbQuery` parameter to further filter results.
        :type table_id: int
        :param hubdb_query: Specify a HubDB query to further filter the search results.
        :type hubdb_query: str
        :param domain: A domain to match search results for. Multiple domains can be provided with &.
        :type domain: list[str]
        :param type: Specifies the type of content to search. Can be one or more of SITE_PAGE, LANDING_PAGE, BLOG_POST, LISTING_PAGE, and KNOWLEDGE_ARTICLE. Defaults to all content types except LANDING_PAGE and KNOWLEDGE_ARTICLE
        :type type: list[str]
        :param path_prefix: Specifies a path prefix to filter search results. Will only return results with URL paths that start with the specified parameter. Can be used multiple times.
        :type path_prefix: list[str]
        :param _property: Specifies which properties to include in the search. Options include `title`, `description`, and `html`. All properties will be searched by default.
        :type _property: list[str]
        :param length: Specifies the length of the search results. Can be set to `LONG` or `SHORT`. `SHORT` will return the first 128 characters of the content's meta description. `LONG` will build a more detailed content snippet based on the html/content of the page.
        :type length: str
        :param group_id: Specifies which blog(s) to be searched by blog ID. Can be used multiple times to search more than one blog.
        :type group_id: list[int]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PublicSearchResults
        """
        kwargs["_return_http_data_only"] = True
        return self.search_with_http_info(**kwargs)  # noqa: E501

    def search_with_http_info(self, **kwargs):  # noqa: E501
        """Search your site.  # noqa: E501

        Returns any website content matching the given search criteria for a given HubSpot account. Searches can be filtered by content type, domain, or URL path.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.search_with_http_info(async_req=True)
        >>> result = thread.get()

        :param q: The term to search for.
        :type q: str
        :param limit: Specifies the number of results to be returned in a single response. Defaults to `10`. Maximum value is `100`.
        :type limit: int
        :param offset: Used to page through the results. If there are more results than specified by the `limit` parameter, you will need to use the value of offset returned in the previous request to get the next set of results.
        :type offset: int
        :param language: Specifies the language of content to be searched. This value must be a valid [ISO 639-1 language code](https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes) (e.g. `es` for Spanish)
        :type language: str
        :param match_prefix: Inverts the behavior of the pathPrefix filter when set to `false`. Defaults to `true`.
        :type match_prefix: bool
        :param autocomplete: Specifies whether or not you are showing autocomplete results. Defaults to false.
        :type autocomplete: bool
        :param popularity_boost: Specifies how strongly a result is boosted based on its view count. Defaults to 1.0.
        :type popularity_boost: float
        :param boost_limit: Specifies the maximum amount a result will be boosted based on its view count. Defaults to 5.0. Read more about elasticsearch boosting [here](https://www.elastic.co/guide/en/elasticsearch/reference/current/mapping-boost.html).
        :type boost_limit: float
        :param boost_recent: Specifies a relative time window where scores of documents published outside this time window decay. This can only be used for blog posts. For example, boostRecent=10d will boost documents published within the last 10 days. Supported timeunits are ms (milliseconds), s (seconds), m (minutes), h (hours), d (days).
        :type boost_recent: str
        :param table_id: Specifies a specific HubDB table to search. Only returns results from the specified table. Can be used in tandem with the `hubdbQuery` parameter to further filter results.
        :type table_id: int
        :param hubdb_query: Specify a HubDB query to further filter the search results.
        :type hubdb_query: str
        :param domain: A domain to match search results for. Multiple domains can be provided with &.
        :type domain: list[str]
        :param type: Specifies the type of content to search. Can be one or more of SITE_PAGE, LANDING_PAGE, BLOG_POST, LISTING_PAGE, and KNOWLEDGE_ARTICLE. Defaults to all content types except LANDING_PAGE and KNOWLEDGE_ARTICLE
        :type type: list[str]
        :param path_prefix: Specifies a path prefix to filter search results. Will only return results with URL paths that start with the specified parameter. Can be used multiple times.
        :type path_prefix: list[str]
        :param _property: Specifies which properties to include in the search. Options include `title`, `description`, and `html`. All properties will be searched by default.
        :type _property: list[str]
        :param length: Specifies the length of the search results. Can be set to `LONG` or `SHORT`. `SHORT` will return the first 128 characters of the content's meta description. `LONG` will build a more detailed content snippet based on the html/content of the page.
        :type length: str
        :param group_id: Specifies which blog(s) to be searched by blog ID. Can be used multiple times to search more than one blog.
        :type group_id: list[int]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PublicSearchResults, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            "q",
            "limit",
            "offset",
            "language",
            "match_prefix",
            "autocomplete",
            "popularity_boost",
            "boost_limit",
            "boost_recent",
            "table_id",
            "hubdb_query",
            "domain",
            "type",
            "path_prefix",
            "_property",
            "length",
            "group_id",
        ]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method search" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if local_var_params.get("q") is not None:  # noqa: E501
            query_params.append(("q", local_var_params["q"]))  # noqa: E501
        if local_var_params.get("limit") is not None:  # noqa: E501
            query_params.append(("limit", local_var_params["limit"]))  # noqa: E501
        if local_var_params.get("offset") is not None:  # noqa: E501
            query_params.append(("offset", local_var_params["offset"]))  # noqa: E501
        if local_var_params.get("language") is not None:  # noqa: E501
            query_params.append(("language", local_var_params["language"]))  # noqa: E501
        if local_var_params.get("match_prefix") is not None:  # noqa: E501
            query_params.append(("matchPrefix", local_var_params["match_prefix"]))  # noqa: E501
        if local_var_params.get("autocomplete") is not None:  # noqa: E501
            query_params.append(("autocomplete", local_var_params["autocomplete"]))  # noqa: E501
        if local_var_params.get("popularity_boost") is not None:  # noqa: E501
            query_params.append(("popularityBoost", local_var_params["popularity_boost"]))  # noqa: E501
        if local_var_params.get("boost_limit") is not None:  # noqa: E501
            query_params.append(("boostLimit", local_var_params["boost_limit"]))  # noqa: E501
        if local_var_params.get("boost_recent") is not None:  # noqa: E501
            query_params.append(("boostRecent", local_var_params["boost_recent"]))  # noqa: E501
        if local_var_params.get("table_id") is not None:  # noqa: E501
            query_params.append(("tableId", local_var_params["table_id"]))  # noqa: E501
        if local_var_params.get("hubdb_query") is not None:  # noqa: E501
            query_params.append(("hubdbQuery", local_var_params["hubdb_query"]))  # noqa: E501
        if local_var_params.get("domain") is not None:  # noqa: E501
            query_params.append(("domain", local_var_params["domain"]))  # noqa: E501
            collection_formats["domain"] = "multi"  # noqa: E501
        if local_var_params.get("type") is not None:  # noqa: E501
            query_params.append(("type", local_var_params["type"]))  # noqa: E501
            collection_formats["type"] = "multi"  # noqa: E501
        if local_var_params.get("path_prefix") is not None:  # noqa: E501
            query_params.append(("pathPrefix", local_var_params["path_prefix"]))  # noqa: E501
            collection_formats["pathPrefix"] = "multi"  # noqa: E501
        if local_var_params.get("_property") is not None:  # noqa: E501
            query_params.append(("property", local_var_params["_property"]))  # noqa: E501
            collection_formats["property"] = "multi"  # noqa: E501
        if local_var_params.get("length") is not None:  # noqa: E501
            query_params.append(("length", local_var_params["length"]))  # noqa: E501
        if local_var_params.get("group_id") is not None:  # noqa: E501
            query_params.append(("groupId", local_var_params["group_id"]))  # noqa: E501
            collection_formats["groupId"] = "multi"  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "PublicSearchResults",
        }

        return self.api_client.call_api(
            "/cms/v3/site-search/search",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )



# coding: utf-8

"""
    CRM Objects

    CRM objects such as companies, contacts, deals, line items, products, tickets, and quotes are standard objects in HubSpot’s CRM. These core building blocks support custom properties, store critical information, and play a central role in the HubSpot application.  ## Supported Object Types  This API provides access to collections of CRM objects, which return a map of property names to values. Each object type has its own set of default properties, which can be found by exploring the [CRM Object Properties API](https://developers.hubspot.com/docs/methods/crm-properties/crm-properties-overview).  |Object Type |Properties returned by default | |--|--| | `companies` | `name`, `domain` | | `contacts` | `firstname`, `lastname`, `email` | | `deals` | `dealname`, `amount`, `closedate`, `pipeline`, `dealstage` | | `products` | `name`, `description`, `price` | | `tickets` | `content`, `hs_pipeline`, `hs_pipeline_stage`, `hs_ticket_category`, `hs_ticket_priority`, `subject` |  Find a list of all properties for an object type using the [CRM Object Properties](https://developers.hubspot.com/docs/methods/crm-properties/get-properties) API. e.g. `GET https://api.hubapi.com/properties/v2/companies/properties`. Change the properties returned in the response using the `properties` array in the request body.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.objects.configuration import Configuration


class PublicObjectSearchRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"query": "str", "limit": "int", "after": "str", "sorts": "list[str]", "properties": "list[str]", "filter_groups": "list[FilterGroup]"}

    attribute_map = {"query": "query", "limit": "limit", "after": "after", "sorts": "sorts", "properties": "properties", "filter_groups": "filterGroups"}

    def __init__(self, query=None, limit=None, after=None, sorts=None, properties=None, filter_groups=None, local_vars_configuration=None):  # noqa: E501
        """PublicObjectSearchRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._query = None
        self._limit = None
        self._after = None
        self._sorts = None
        self._properties = None
        self._filter_groups = None
        self.discriminator = None

        if query is not None:
            self.query = query
        if limit is not None:
            self.limit = limit
        if after is not None:
            self.after = after
        if sorts is not None:
            self.sorts = sorts
        if properties is not None:
            self.properties = properties
        if filter_groups is not None:
            self.filter_groups = filter_groups

    @property
    def query(self):
        """Gets the query of this PublicObjectSearchRequest.  # noqa: E501


        :return: The query of this PublicObjectSearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """Sets the query of this PublicObjectSearchRequest.


        :param query: The query of this PublicObjectSearchRequest.  # noqa: E501
        :type query: str
        """

        self._query = query

    @property
    def limit(self):
        """Gets the limit of this PublicObjectSearchRequest.  # noqa: E501


        :return: The limit of this PublicObjectSearchRequest.  # noqa: E501
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this PublicObjectSearchRequest.


        :param limit: The limit of this PublicObjectSearchRequest.  # noqa: E501
        :type limit: int
        """

        self._limit = limit

    @property
    def after(self):
        """Gets the after of this PublicObjectSearchRequest.  # noqa: E501


        :return: The after of this PublicObjectSearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._after

    @after.setter
    def after(self, after):
        """Sets the after of this PublicObjectSearchRequest.


        :param after: The after of this PublicObjectSearchRequest.  # noqa: E501
        :type after: str
        """

        self._after = after

    @property
    def sorts(self):
        """Gets the sorts of this PublicObjectSearchRequest.  # noqa: E501


        :return: The sorts of this PublicObjectSearchRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._sorts

    @sorts.setter
    def sorts(self, sorts):
        """Sets the sorts of this PublicObjectSearchRequest.


        :param sorts: The sorts of this PublicObjectSearchRequest.  # noqa: E501
        :type sorts: list[str]
        """

        self._sorts = sorts

    @property
    def properties(self):
        """Gets the properties of this PublicObjectSearchRequest.  # noqa: E501


        :return: The properties of this PublicObjectSearchRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this PublicObjectSearchRequest.


        :param properties: The properties of this PublicObjectSearchRequest.  # noqa: E501
        :type properties: list[str]
        """

        self._properties = properties

    @property
    def filter_groups(self):
        """Gets the filter_groups of this PublicObjectSearchRequest.  # noqa: E501


        :return: The filter_groups of this PublicObjectSearchRequest.  # noqa: E501
        :rtype: list[FilterGroup]
        """
        return self._filter_groups

    @filter_groups.setter
    def filter_groups(self, filter_groups):
        """Sets the filter_groups of this PublicObjectSearchRequest.


        :param filter_groups: The filter_groups of this PublicObjectSearchRequest.  # noqa: E501
        :type filter_groups: list[FilterGroup]
        """

        self._filter_groups = filter_groups

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicObjectSearchRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicObjectSearchRequest):
            return True

        return self.to_dict() != other.to_dict()
